=======
General
=======

About MoinMoin
--------------
MoinMoin is a wiki engine written in Python. It is Free and Open Source
Software under GNU GPL v2+. For details please read the :ref:`license`.

Project homepage: https://moinmo.in/

Using MoinMoin, wiki users can easily create and maintain web content from
their browser.

You can use it:

* as an easily-maintained web site
* as a knowledge base
* for taking notes
* for creating documentation

You can use it for:

* your company / organization, your work group
* your school, college, or university
* your projects and interests
* just yourself

You can run it on:

* a public web server
* an intranet server
* your desktop or laptop
* Linux, macOS, Windows, and other OSes


What makes MoinMoin special?
----------------------------
Moin tries to be a **great wiki engine**, which encompasses: powerful, extendable and
easy-to-use. We don't try to be everything, but we don't try to be
minimalistic either.

There are lots of wiki engines out there, making it hard to pick one.
However, choosing wisely is important because you may have to live with
your choice for a long time because switching wiki engines is not easy.

We won't list all of Moin's features, because comparing feature lists
is just not enough. Some features are best left unimplemented,
even if they sound great at first. In Moin, you will find most
important features like in most major wiki engines. But still, you and your wiki
users might feel quite a different overall experience just because of a bunch
of small, superficial differences. Of course the quality of some features'
implementations can vary greatly. Thus, you have to
try it and play with it, not just look at feature comparisons.

MoinMoin has **been around since about 2000**.
It has rapidly grown and evolved through moin 1.9.x. Its developers have
increased their experience with Python and wiki technology over the years.
With **moin 2.0**, there has been a rather **revolutionary cleanup / rewrite**
of how Moin works based on that experience. This promises to make it easier,
cleaner, more consistent, more powerful, more flexible and more
modular.

Moin is **written in Python**, an easy to read, high-level, object-oriented,
dynamic, well-designed and platform-independent programming language.

Moin is **Free Software** (that implies that it is **Open Source**) and,
because we use Python, you may even *like* to read and modify Moin's code.


Who is using MoinMoin?
----------------------
This shows some of the better-known users of MoinMoin:

Websites
~~~~~~~~~
* KernelNewbies, Xen, LinuxWireless, GCC
* Debian, Ubuntu, CentOS
* Apache, GNOME, Wine, OpenOffice, Squid, Exim, Dovecot
* Python, SciPy, TurboGears
* Mercurial, Darcs
* FSFE, FFII, c-base, MusicBrainz
* linuxwiki.de, jurawiki.de, ooowiki.de and ... moinmo.in :D

For links and more sites, please see: https://moinmo.in/MoinMoinWikis

You may also add missing moin-based sites there.


Intranet installations
~~~~~~~~~~~~~~~~~~~~~~
We know that there are a lot of private intranet installations of
MoinMoin in:

* enterprises, companies
* government and administration
* scientific research facilities, universities, schools
* communities

Unfortunately, we do not have permission to name them here.
